IdsTypography class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bodyB1Bold → const TextStyle
bodyB1Medium → const TextStyle
bodyB1Regular → const TextStyle
bodyB1Semibold → const TextStyle
bodyB2Bold → const TextStyle
bodyB2Medium → const TextStyle
bodyB2Regular → const TextStyle
bodyB2Semibold → const TextStyle
bodyB3Bold → const TextStyle
bodyB3Medium → const TextStyle
bodyB3Regular → const TextStyle
bodyB3Semibold → const TextStyle
buttonStandard → const TextStyle
buttonTiny → const TextStyle
captionC1Medium → const TextStyle
captionC1Regular → const TextStyle
captionC1Semibold → const TextStyle
captionC2Medium → const TextStyle
captionC2Regular → const TextStyle
captionC2Semibold → const TextStyle
headlineH1Bold → const TextStyle
headlineH1Medium → const TextStyle
headlineH1Semibold → const TextStyle
headlineH2Bold → const TextStyle
headlineH2Medium → const TextStyle
headlineH2Semibold → const TextStyle
headlineH3Bold → const TextStyle
headlineH3Medium → const TextStyle
headlineH3Semibold → const TextStyle
headlineH4Bold → const TextStyle
headlineH4Medium → const TextStyle
headlineH4Semibold → const TextStyle
headlineH5Bold → const TextStyle
headlineH5Medium → const TextStyle
headlineH5Semibold → const TextStyle
headlineH6Bold → const TextStyle
headlineH6Medium → const TextStyle
headlineH6Semibold → const TextStyle
sansFontFamily → const String
sansFontPackage → const String
subtitleS1Bold → const TextStyle
subtitleS1Medium → const TextStyle
subtitleS1Semibold → const TextStyle
subtitleS2Bold → const TextStyle
subtitleS2Medium → const TextStyle
subtitleS2Semibold → const TextStyle