IdsTheme class
Properties
- color → IdsColor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDark → bool
-
no setter
- mode → IdsMode
-
final
- muted → Color
-
no setter
- onMuted → Color
-
no setter
- onPrimary → Color
-
no setter
- onSecondary → Color
-
no setter
- onSurface → Color
-
no setter
- outline → Color
-
no setter
- primary → Color
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Color
-
no setter
- surface → Color
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String token) → Color -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited